Index: chrome/browser/tab_contents/tab_contents_delegate.h |
diff --git a/chrome/browser/tab_contents/tab_contents_delegate.h b/chrome/browser/tab_contents/tab_contents_delegate.h |
index c9ace5d953f1e68fb29a158058ddb3f1917c5897..09c560d10cce42fa656895aefff5eafe0f60acfd 100644 |
--- a/chrome/browser/tab_contents/tab_contents_delegate.h |
+++ b/chrome/browser/tab_contents/tab_contents_delegate.h |
@@ -249,8 +249,9 @@ class TabContentsDelegate : public AutomationResourceRoutingDelegate { |
const NavigationEntry::SSLStatus& ssl, |
bool show_history); |
- // Opens source view for given tab contents. |
- virtual void ViewSourceForTab(TabContents* source); |
+ // Opens source view for given tab contents that is navigated to the given |
+ // page url. |
+ virtual void ViewSourceForTab(TabContents* source, const GURL& page_url); |
// Allows delegates to handle keyboard events before sending to the renderer. |
// Returns true if the |event| was handled. Otherwise, if the |event| would be |